import React, { useCallback, useMemo } from 'react';
import { HandleLinkPressFeature, ForceResponsiveViewportFeature, useWebshell } from '@formidable-webview/webshell';
const features = [new HandleLinkPressFeature({
  preventDefault: true
})];
/**
 * A component to render iframes in react-native-render-html.
 *
 * @public
 */

export default function HTMLIframe({
  WebView,
  webViewProps: userWebViewProps,
  source,
  style,
  onLinkPress,
  htmlAttribs,
  scaleFactor,
  scalesPageToFit = false
}) {
  const scaleFeature = useMemo(() => scalesPageToFit ? new ForceResponsiveViewportFeature({
    initScale: scaleFactor,
    maxScale: scaleFactor,
    minScale: scaleFactor
  }) : null, [scaleFactor, scalesPageToFit]);
  const onDOMLinkPress = useCallback(({
    uri
  }) => onLinkPress === null || onLinkPress === void 0 ? void 0 : onLinkPress.call(null, {
    nativeEvent: {}
  }, uri, htmlAttribs, htmlAttribs.target || '_self'), [onLinkPress, htmlAttribs]);
  const webViewProps = useWebshell({
    features: [...features, scaleFeature],
    props: { ...userWebViewProps,
      onDOMLinkPress,
      style,
      source,
      testID: 'iframe'
    }
  });
  return /*#__PURE__*/React.createElement(WebView, webViewProps);
}
//# sourceMappingURL=HTMLIframe.js.map